# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.personas_instances_response import PersonasInstancesResponse

class TestPersonasInstancesResponse(unittest.TestCase):
    """PersonasInstancesResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PersonasInstancesResponse:
        """Test PersonasInstancesResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PersonasInstancesResponse`
        """
        model = PersonasInstancesResponse()
        if include_optional:
            return PersonasInstancesResponse(
                data = [
                    neurograph.v1.models.personas/persona.personas.Persona(
                        age = 1.337, 
                        description = '', 
                        factors = [
                            neurograph.v1.models.personas/persona_factor.personas.PersonaFactor(
                                detail = '', 
                                display = '', 
                                id = 56, 
                                name = '', 
                                persona_instance_id = '', 
                                summary = '', 
                                value = 56, )
                            ], 
                        female = 1.337, 
                        id = '', 
                        income = '', 
                        insights = [
                            neurograph.v1.models.personas/persona_insight.personas.PersonaInsight(
                                data = neurograph.v1.models.data.data(), 
                                id = 56, 
                                key = '', 
                                persona_instance_id = 56, )
                            ], 
                        kpis = [
                            neurograph.v1.models.personas/kpi.personas.Kpi(
                                id = 56, 
                                name = '', 
                                persona_instance_id = '', 
                                value = '', )
                            ], 
                        male = 1.337, 
                        match_criteria = [
                            neurograph.v1.models.personas/match_criteria_row_in_db.personas.MatchCriteriaRowInDb(
                                concept = '', 
                                detail = '', 
                                display = '', 
                                error = '', 
                                id = 56, 
                                persona_instance_id = '', )
                            ], 
                        metadata = '', 
                        name = '', 
                        persona_seed_id = '', 
                        personality_background = '', 
                        personality_first_name = '', 
                        personality_img_url = '', 
                        personality_last_name = '', 
                        personality_quote = '', 
                        personality_traits = [
                            neurograph.v1.models.personas/persona_personality_trait.personas.PersonaPersonalityTrait(
                                id = 56, 
                                name = '', 
                                persona_instance_id = '', 
                                traits = [
                                    ''
                                    ], )
                            ], 
                        personality_video_url = '', 
                        positioning_statement = '', 
                        seed_uid = '', 
                        summary_detail = '', 
                        summary_headline = '', 
                        tag = '', 
                        ts_created = 56, 
                        ts_updated = 56, 
                        value = '', )
                    ],
                error = '',
                query_limit = 56,
                query_offset = 56,
                total_rows = 56
            )
        else:
            return PersonasInstancesResponse(
        )
        """

    def testPersonasInstancesResponse(self):
        """Test PersonasInstancesResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
