# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.api.persona_api import PersonaApi


class TestPersonaApi(unittest.TestCase):
    """PersonaApi unit test stubs"""

    def setUp(self) -> None:
        self.api = PersonaApi()

    def tearDown(self) -> None:
        pass

    def test_api_v1_persona_factors_post(self) -> None:
        """Test case for api_v1_persona_factors_post

        Create Persona Factors
        """
        pass

    def test_api_v1_persona_insight_post(self) -> None:
        """Test case for api_v1_persona_insight_post

        Create a Persona Insight
        """
        pass

    def test_api_v1_persona_instance_delete(self) -> None:
        """Test case for api_v1_persona_instance_delete

        Delete one or more Persona Instances and associated data
        """
        pass

    def test_api_v1_persona_instance_get(self) -> None:
        """Test case for api_v1_persona_instance_get

        Get Persona Instances and all associated data
        """
        pass

    def test_api_v1_persona_instance_post(self) -> None:
        """Test case for api_v1_persona_instance_post

        Create a Persona Instance
        """
        pass

    def test_api_v1_persona_kpi_post(self) -> None:
        """Test case for api_v1_persona_kpi_post

        Create Persona KPIs
        """
        pass

    def test_api_v1_persona_match_criteria_post(self) -> None:
        """Test case for api_v1_persona_match_criteria_post

        Create Persona Match Criteria
        """
        pass

    def test_api_v1_persona_personality_trait_post(self) -> None:
        """Test case for api_v1_persona_personality_trait_post

        Create a Persona Traits
        """
        pass

    def test_api_v1_persona_seed_get(self) -> None:
        """Test case for api_v1_persona_seed_get

        Get one or more Persona Seeds
        """
        pass

    def test_api_v1_persona_seed_post(self) -> None:
        """Test case for api_v1_persona_seed_post

        Upsert a Persona Seed
        """
        pass

    def test_api_v1_persona_seed_seed_id_delete(self) -> None:
        """Test case for api_v1_persona_seed_seed_id_delete

        Delete a persona seed
        """
        pass

    def test_api_v1_persona_seed_seed_id_status_put(self) -> None:
        """Test case for api_v1_persona_seed_seed_id_status_put

        Toggle a Persona Seed
        """
        pass


if __name__ == '__main__':
    unittest.main()
