# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.reporting_daily_metrics_response import ReportingDailyMetricsResponse

class TestReportingDailyMetricsResponse(unittest.TestCase):
    """ReportingDailyMetricsResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ReportingDailyMetricsResponse:
        """Test ReportingDailyMetricsResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ReportingDailyMetricsResponse`
        """
        model = ReportingDailyMetricsResponse()
        if include_optional:
            return ReportingDailyMetricsResponse(
                data = [
                    neurograph.v1.models.reporting/daily_metric.reporting.DailyMetric(
                        avg_lifetime_value = 1.337, 
                        avg_ltv_original = 1.337, 
                        customers_with_orders = 56, 
                        data_quality_flag = '', 
                        iqr_avg_ltv = 1.337, 
                        median_ltv = 1.337, 
                        outlier_count = 56, 
                        p25_ltv = 1.337, 
                        p75_ltv = 1.337, 
                        persona_name = '', 
                        total_customers = 56, 
                        trimmed_avg_ltv = 1.337, 
                        winsorized_avg_ltv = 1.337, )
                    ],
                error = ''
            )
        else:
            return ReportingDailyMetricsResponse(
        )
        """

    def testReportingDailyMetricsResponse(self):
        """Test ReportingDailyMetricsResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
